@@ -1,44 +1,25 @@
+from swarms.agents.agent_judge import AgentJudge
 from swarms.agents.consistency_agent import SelfConsistencyAgent
-
-# from swarms.agents.tool_agent import ToolAgent
 from swarms.agents.create_agents_from_yaml import (
     create_agents_from_yaml,
 )
+from swarms.agents.flexion_agent import ReflexionAgent
+from swarms.agents.gkp_agent import GKPAgent
 from swarms.agents.i_agent import IterativeReflectiveExpansion
 from swarms.agents.reasoning_agents import (
     ReasoningAgentRouter,
     agent_types,
 )
 from swarms.agents.reasoning_duo import ReasoningDuo
-from swarms.structs.stopping_conditions import (
-    check_cancelled,
-    check_complete,
-    check_done,
-    check_end,
-    check_error,
-    check_exit,
-    check_failure,
-    check_finished,
-    check_stopped,
-    check_success,
-)
 
 __all__ = [
-    # "ToolAgent",
-    "check_done",
-    "check_finished",
-    "check_complete",
-    "check_success",
-    "check_failure",
-    "check_error",
-    "check_stopped",
-    "check_cancelled",
-    "check_exit",
-    "check_end",
     "create_agents_from_yaml",
     "IterativeReflectiveExpansion",
     "SelfConsistencyAgent",
     "ReasoningDuo",
     "ReasoningAgentRouter",
     "agent_types",
+    "ReflexionAgent",
+    "GKPAgent",
+    "AgentJudge",
 ]
