@@ -7,6 +7,7 @@ from swarms.prompts.operations_agent_prompt import (
     OPERATIONS_AGENT_PROMPT,
 )
 from swarms.prompts.product_agent_prompt import PRODUCT_AGENT_PROMPT
+from swarms.prompts.prompt import Prompt
 
 __all__ = [
     "CODE_INTERPRETER",
@@ -16,4 +17,5 @@ __all__ = [
     "OPERATIONS_AGENT_PROMPT",
     "PRODUCT_AGENT_PROMPT",
     "DOCUMENTATION_WRITER_SOP",
+    "Prompt",
 ]
